# Changelog for sagemcom-f3896lg-zg-api

## Version 0.1.0

The initial version of the sagemcom-f3896lg-zg-api library. This includes the base SagemcomF3896LGApi
with support for listing connected devices.
